@@ -21,8 +21,8 @@ import unittest
 import sys
 
 print('Running tests using %s' % sys.version)
-if sys.version_info.major != 3 or sys.version_info.minor < 8:
-    raise Exception('Only version 3.8 and above supported')
+if sys.version_info.major != 3 or sys.version_info.minor < 9:
+    raise Exception('Only version 3.9 and above supported')
 
 from .test_dataloader import *
 from .test_datadumper import *
@@ -39,6 +39,9 @@ from .test_typeddict import *
 if sys.version_info.minor >= 10:
     from .test_orunion import *
 
+if sys.version_info.minor >= 12:
+    from .test_typealias import *
+
 # Run tests for attr only if it is installed
 try:
     import attr
