@@ -270,10 +270,6 @@ class TestAttrConverter(unittest.TestCase):
             load({'a': 'a', 'b': 1}, C)
 
     def test_typed_conversion(self):
-        if sys.version_info.minor < 8:
-            # Skip for older than 3.8
-            return
-
         from typing import Literal
 
         @define
