@@ -1,5 +1,5 @@
 # typedload
-# Copyright (C) 2018-2023 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2018-2024 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -276,7 +276,7 @@ class TestNamedTuple(unittest.TestCase):
         assert loader.load({'a': 1, 'b': 1}, A) == r
         assert loader.load({'a': 1, 'b': 1, 'c': 3}, A) == r
         loader.failonextra = True
-        with self.assertRaises(ValueError):
+        with self.assertRaises(TypeError):
             loader.load({'a': 1, 'b': 1, 'c': 3}, A)
 
     def test_simple_defaults(self):
@@ -304,7 +304,7 @@ class TestNamedTuple(unittest.TestCase):
             a: int
             q: str
         loader = dataloader.Loader()
-        with self.assertRaises(ValueError):
+        with self.assertRaises(TypeError):
             loader.load({'a': 3}, A)
 
 
@@ -423,12 +423,13 @@ class TestExceptions(unittest.TestCase):
             assert e.trace[-1].annotation[1] == 'a'
 
         try:
-            loader.load({'a':'q','b': {'a': 1}}, B)
+            loader.load({'a':'q','b': 1}, B)
         except Exception as e:
+            print(e.trace)
             assert e.trace[-1].annotation[1] == 'a'
 
         try:
-            loader.load({'a':3,'b': {'a': 'q'}}, B)
+            loader.load({'a':3,'b': 1}, B)
         except Exception as e:
             assert e.trace[-1].annotation[1] == 'a'
 
