@@ -154,7 +154,7 @@ class Dumper:
         ]  # type: List[Tuple[Callable[[Any], bool], Callable[['Dumper', Any, Any], Any]|Callable[['Dumper', Any], Any]]]
 
         self._handlerscache = {}  # type: Dict[Type[Any], Callable[['Dumper', Any, Any], Any]]
-        self._dataclasscache = {}  # type: Dict[Type[Any], Tuple[Set[str], Dict[str, Any], Dict[str, Any], Dict[str, str], Set[str]]]
+        self._dataclasscache = {}  # type: Dict[Type[Any], Tuple[Set[str], Dict[str, Any], Dict[str, Any], Dict[str, str], Set[str], bool]]
 
         for k, v in kwargs.items():
             setattr(self, k, v)
@@ -263,7 +263,7 @@ def _namedtupledump(d: Dumper, value, t) -> Dict[str, Any]:
 def _dataclassdump(d: Dumper, value, t) -> Dict[str, Any]:
     t = type(value)
     try:
-        fields, defaults, type_hints, renames, needs_dump  = d._dataclasscache[t]
+        fields, defaults, type_hints, renames, needs_dump, hasdict  = d._dataclasscache[t]
     except KeyError:
         from dataclasses import _MISSING_TYPE as DT_MISSING_TYPE
         fields = set(value.__dataclass_fields__.keys())
@@ -277,10 +277,16 @@ def _dataclassdump(d: Dumper, value, t) -> Dict[str, Any]:
             k for k,v in value.__dataclass_fields__.items()
             if (v.type in d.basictypes and d.handlers[0][1] == _identitydump) or is_literal(v.type)
         })
+        hasdict = hasattr(value, '__dict__')
 
-        d._dataclasscache[t] = (fields, defaults, type_hints, renames, needs_dump)
+        d._dataclasscache[t] = (fields, defaults, type_hints, renames, needs_dump, hasdict)
+
+    if hasdict:
+        r = value.__dict__.copy()
+    else:
+        # Slow method if the __dict__ member is not present
+        r = {f: getattr(value, f) for f in fields}
 
-    r = value.__dict__.copy()
     for k in fields:
         if not d.hidedefault or k not in defaults or defaults[k] != r[k]:
             if k in needs_dump:
