@@ -35,6 +35,17 @@ from .typechecks import *
 from .typechecks import discriminatorliterals
 from .helpers import tname
 
+try:
+    # A dirty trick
+    #
+    # The alias module has a syntax that won't work on
+    # older python versions, so we only import it
+    # from 3.12 onwards (which is also where it can be used)
+    from typing import TypeAliasType  # type: ignore
+    from .alias import unalias  # type: ignore
+except ImportError:
+    unalias = None  # type: ignore
+
 
 __all__ = [
     'Loader',
@@ -283,6 +294,9 @@ class Loader:
         It is only needed when calling load recursively from
         a custom handler.
         """
+        if unalias:
+            type_ = unalias(type_)  # type: ignore
+
         cached_f = self._indexcache.get(type_)
 
         if cached_f is not None:
@@ -513,7 +527,10 @@ def _dataclassload(l: Loader, value: Dict[str, Any], type_) -> Any:
         if l.pep563:
             type_hints = get_type_hints(type_)
         else:
-            type_hints = {k: v.type for k,v in type_.__dataclass_fields__.items()}
+            if unalias:
+                type_hints = {k: unalias(v.type) for k,v in type_.__dataclass_fields__.items()}
+            else:
+                type_hints = {k: v.type for k,v in type_.__dataclass_fields__.items()}
 
         #Name mangling
 
@@ -643,7 +660,10 @@ def _namedtupleload(l: Loader, value: Any, type_) -> Any:
         if l.pep563:
             type_hints = get_type_hints(type_)
         else:
-            type_hints = type_.__annotations__
+            if unalias:
+                type_hints = {k: unalias(v) for k,v in type_.__annotations__.items()}
+            else:
+                type_hints = type_.__annotations__
         fields = set(type_hints.keys())
         optional_fields = set(getattr(type_, '_field_defaults', {}).keys())
         necessary_fields = fields.difference(optional_fields)
@@ -657,28 +677,39 @@ def _typeddictload(l: Loader, value: Any, type_) -> Any:
     """
     This loads a Dict[str, Any] into a NamedTuple.
     """
-    if l.pep563:
-        type_hints = get_type_hints(type_)
-    else:
-        type_hints = type_.__annotations__
-    fields = set(type_hints.keys())
+    try:
+        fields, necessary_fields, type_hints = l._objfieldscache[type_]
+    except KeyError:
+        if l.pep563:
+            type_hints = get_type_hints(type_)
+        else:
+            type_hints = type_.__annotations__
+        fields = set(type_hints.keys())
 
-    if hasattr(type_, '__required_keys__') and hasattr(type_, '__optional_keys__'):
-        # TypedDict, since 3.9
-        necessary_fields = set(type_.__required_keys__)
-    elif not type_.__total__:
-        necessary_fields = set()
-    else:
-        necessary_fields = fields
+        if hasattr(type_, '__required_keys__') and hasattr(type_, '__optional_keys__'):
+            # TypedDict, since 3.9
+            necessary_fields = set(type_.__required_keys__)
+        elif not type_.__total__:
+            necessary_fields = set()
+        else:
+            necessary_fields = fields
 
-    # Resolve the NotRequired/Required stuff
-    for k, v in type_hints.items():
-        if is_notrequired(v):
-            type_hints[k] = notrequiredtype(v)
-            necessary_fields.discard(k)
-        elif is_required(v):
-            type_hints[k] = requiredtype(v)
-            necessary_fields.add(k)
+        # Resolve the NotRequired/Required stuff
+        for k, v in type_hints.items():
+            while True:
+                if is_notrequired(v):
+                    v = type_hints[k] = notrequiredtype(v)
+                    necessary_fields.discard(k)
+                elif is_required(v):
+                    v = type_hints[k] = requiredtype(v)
+                    necessary_fields.add(k)
+                elif is_readonly(v):
+                    v = type_hints[k] = readonlytype(v)
+                else:
+                    break
+        if unalias:
+            type_hints = {k: unalias(v) for k, v in type_hints.items()}
+        l._objfieldscache[type_] = fields, necessary_fields, type_hints
 
     return _objloader(l, fields, necessary_fields, type_hints, value, type_, True)
 
@@ -901,7 +932,10 @@ def _attrload(l: Loader, value: Any, type_) -> Any:
 
         fields = {i.name for i in type_.__attrs_attrs__}
         necessary_fields = set()
-        type_hints = {i.name: (_get_attr_converter_type(i.converter) if i.converter else i.type) for i in type_.__attrs_attrs__}
+        if unalias:
+            type_hints = {i.name: (_get_attr_converter_type(i.converter) if i.converter else unalias(i.type)) for i in type_.__attrs_attrs__}
+        else:
+            type_hints = {i.name: (_get_attr_converter_type(i.converter) if i.converter else i.type) for i in type_.__attrs_attrs__}
         namesmap = {}
 
         for attribute in type_.__attrs_attrs__:
