@@ -58,8 +58,10 @@ __all__ = [
     'is_optional',
     'is_notrequired',
     'is_required',
+    'is_readonly',
     'notrequiredtype',
     'requiredtype',
+    'readonlytype',
     'uniontypes',
     'literalvalues',
     'NONETYPE',
@@ -86,6 +88,12 @@ except ImportError:
     NotRequired = None
     Required = None
 
+try:
+    # Since 3.13
+    from typing import ReadOnly  # type: ignore
+except ImportError:
+    ReadOnly = None
+
 
 HAS_TUPLEARGS = True # Legacy, used to be dependant on python version, but I exported the symbol
 NONETYPE = type(None)  # type: Any
@@ -99,7 +107,6 @@ def is_tuple(type_: Any) -> bool:
     '''
     return _generic_type_check(type_, tuple, Tuple)
 
-
 if UnionType:
     # Uniontype is 3.10 defined on 3.10 and None otherwise
     def is_union(type_: Any) -> bool:
@@ -276,6 +283,19 @@ def is_any(type_: Any) -> bool:
     '''
     return type_ == Any
 
+if ReadOnly:
+    def is_readonly(type_: Any) -> bool:
+        '''
+        Check if it's typing.ReadOnly or typing_extensions.ReadOnly
+        '''
+        return getattr(type_, '__origin__', None) == ReadOnly
+else:
+    def is_readonly(type_: Any) -> bool:
+        '''
+        Returns False.
+        ReadOnly is not defined on this platform.
+        '''
+        return False
 
 if NotRequired:
     def is_notrequired(type_: Any) -> bool:
@@ -309,12 +329,12 @@ else:
 
 def notrequiredtype(type_: Any) -> Type[Any]:
     '''
-    Return the type wrapped by Required/NotRequired
+    Return the type wrapped by Required/NotRequired/ReadOnly
     '''
     return type_.__args__[0]
 
 
-requiredtype = notrequiredtype
+readonlytype = requiredtype = notrequiredtype
 
 
 def discriminatorliterals(type_: Any) -> Dict[str, Set[Any]]:
